﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using System.Web.Routing;
using Veritas.BusinessLayer.Logging;
using Veritas.UI.Web.Controllers;

namespace Veritas.UI.Web
{
    // Note: For instructions on enabling IIS6 or IIS7 classic mode, 
    // visit http://go.microsoft.com/?LinkId=9394801

    public class MvcApplication : System.Web.HttpApplication
    {
        public static void RegisterRoutes(RouteCollection routes)
        {
            routes.IgnoreRoute("{resource}.axd/{*pathInfo}");

            routes.MapRoute(
                "Default", // Route name
                "{controller}/{action}/{id}", // URL with parameters
                new { controller = "Home", action = "Index", id = UrlParameter.Optional } // Parameter defaults
            );

        }

        protected void Application_Start()
        {
            AreaRegistration.RegisterAllAreas();

            RegisterRoutes(RouteTable.Routes);
        }

        protected void Application_Error()
        {
            Exception exception = Server.GetLastError();
            HttpException httpException = exception as HttpException;
            RouteData routeData = new RouteData();
            routeData.Values.Add("controller", "Error");
            if (httpException == null)
            {
                LoggingHandler.Log(exception, "Global-Error");
            }
            else
            {
                switch (httpException.GetHttpCode())
                {
                    case 404:      // Page not found.
                        LoggingHandler.Log(exception, "Global-Error", "Warn");
                        routeData.Values.Add("action", "NotFound");
                        break;
                    case 500:     // Server error.                               
                        LoggingHandler.Log(exception, "Global-Error");
                        routeData.Values.Add("action", "InternalServerError");
                        break;
                    default: //Handle any other errors the same as a 500                        
                        LoggingHandler.Log(exception, "Global-Error");
                        routeData.Values.Add("action", "InternalServerError");
                        break;
                }
            }
            // Pass exception details to the target error View. 
            routeData.Values.Add("error", exception);
            // Clear the error on server. 
            Server.ClearError();
            // Call target ErrorController and pass the routeData. 
            IController errorController = new ErrorController();
            errorController.Execute(new RequestContext(new HttpContextWrapper(Context), routeData));
        }
    }
}